ArmBreadcrumb class

Annotations

Constructors

ArmBreadcrumb({required String message, required String level, required DateTime timestamp, String? category, Map<String, dynamic>? data})
const

Properties

category String?
final
data Map<String, dynamic>?
final
hashCode int
The hash code for this object.
no setterinherited
level String
final
message String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited