ArmCaptureRequest class
Constructors
-
ArmCaptureRequest({required ArmSeverity severity, required String category, required String feature, required String operation, required String message, required String errorType, required String stackTrace, required String fingerprint, required String sessionId, required List<
ArmBreadcrumb> breadcrumbs, required Map<String, dynamic> context, required Map<String, dynamic> tags, Map<String, dynamic> ? recoverySnapshot, ArmBinaryAttachment? screenshot, bool handled = false}) -
const
Properties
-
final
- category → String
-
final
-
context
→ Map<
String, dynamic> -
final
- errorType → String
-
final
- feature → String
-
final
- fingerprint → String
-
final
- handled → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- operation → String
-
final
-
recoverySnapshot
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenshot → ArmBinaryAttachment?
-
final
- sessionId → String
-
final
- severity → ArmSeverity
-
final
- stackTrace → String
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited